app/soc/models/role.py
changeset 1085 0afbdd0905ef
parent 1076 063194eaf87b
child 1090 e4c2ccbeb25a
--- a/app/soc/models/role.py	Fri Jan 30 17:23:19 2009 +0000
+++ b/app/soc/models/role.py	Fri Jan 30 17:38:28 2009 +0000
@@ -291,18 +291,18 @@
   agreed_to_tos_on.help_text = ugettext(
       'Indicates when the user agreed to this role Terms of Service.')
 
   #: field storing the state of this role
   #: Active means that this role can exercise all it's privileges.
   #: Invalid mean that this role cannot exercise it's privileges.
   #: Inactive means that this role cannot exercise it's data-editing
   #: privileges but should be able to see the data. For instance when a program
   #: has been marked inactive an Organization Admin should still be able to see
   #: the student applications.
-  state = db.StringProperty(default='active',
+  status = db.StringProperty(default='active',
       choices=['active','invalid','inactive'],
-      verbose_name=ugettext('State of this Role'))
-  state.help_text = ugettext(
-      'Indicates the state of the role concerning which privileges may be used')
+      verbose_name=ugettext('Status of this Role'))
+  status.help_text = ugettext(
+      'Indicates the status of the role concerning which privileges may be used')
 
 
   def name(self):
@@ -291,18 +291,18 @@
       'Indicates when the user agreed to this role Terms of Service.')
 
-  #: field storing the state of this role
+  #: field storing the status of this role
   #: Active means that this role can exercise all it's privileges.
   #: Invalid mean that this role cannot exercise it's privileges.